cropImage method
Performs cropping, rotation, and flipping on a saved image bitmap. This operation is performed on the native side for performance.
Implementation
Future<String?> cropImage({
required String path,
required int x,
required int y,
required int width,
required int height,
int rotationDegrees = 0,
bool flipX = false,
int quality = 100,
}) async {
return await FlutterCropCameraPlatform.instance.cropImage(
path: path,
x: x,
y: y,
width: width,
height: height,
rotationDegrees: rotationDegrees,
flipX: flipX,
quality: quality,
);
}