FlutterCropCameraWeb class
Stub for VM/mobile targets so flutter_crop_camera.dart does not pull
flutter_web_plugins / dart:ui_web (only valid on web).
The real implementation is selected via conditional export when
dart.library.html is available.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
[Object? _]) → void